using System;
using System.Collections.Generic;
using Castle.ActiveRecord;

namespace AutoDbCreate.WebHost.Services
{
    public interface IRepository<T>
    {
        void Create(T item);
        T Find(int id); 
        IEnumerable<T> FindAll();
        void Delete(T item);
        void Update(T item);
        IDisposable GetTransactionScope(); 
    }


    public class Repository<T> : IRepository<T> where T : class
    {
        public void Create(T item)
        {
            ActiveRecordMediator<T>.Create(item);
        }

        public T Find(int id)
        {
            return ActiveRecordMediator<T>.FindByPrimaryKey(id, false);
        }

        public IEnumerable<T> FindAll()
        {
            return ActiveRecordMediator<T>.FindAll(); 
        }

        public void Delete(T item)
        {
            ActiveRecordMediator<T>.Delete(item); 
        }

        public void Update(T item)
        {
            ActiveRecordMediator<T>.Update(item);
        }

        public IDisposable GetTransactionScope()
        {
            return new TransactionScope();
        }
    }

    
}